CREATE DATABASE IF NOT EXISTS tt4;

DROP TABLE IF EXISTS tt4.`tt_prediction_models`;
CREATE TABLE tt4.`tt_prediction_models` (
  `section` varchar(32) COLLATE utf8_czech_ci NOT NULL COMMENT 'Unique identifier of map section',
  `model_dump` longtext CHARACTER SET utf8 NOT NULL COMMENT 'Base64, zlib, binary encoded JSON representaion of model',
  `model_type` varchar(25) CHARACTER SET utf8 NOT NULL COMMENT 'Type of model',
  `model_parameters` varchar(2048) CHARACTER SET utf8 DEFAULT NULL COMMENT 'Hyperparameters used for model training',
  `used_sensors` varchar(256) CHARACTER SET utf8 NOT NULL COMMENT 'Data from which sensors were used for the training of the model',
  `time_from` datetime NOT NULL COMMENT 'The earliest timestamp of data used for trainign of this model' ,
  `time_to` datetime NOT NULL COMMENT 'The latest timestamp of data used for training of this model',
  `insert_timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Timestamp for insertion of record into DB',
  `update_timestamp` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`section`,`model_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

DROP TABLE IF EXISTS tt4.`tt_prediction_results`;
CREATE TABLE tt4.`tt_prediction_results` (
  `output_section` varchar(32) COLLATE utf8_czech_ci NOT NULL COMMENT 'Output section identifier',
  `calculation_time` datetime NOT NULL COMMENT 'End of calculation time interval (CTI) for which TT is calculated (UTC)',
  `calculation_time_local` datetime NOT NULL COMMENT 'As calculation time but in local timezone',
  `tt_calculated` int(11) DEFAULT NULL COMMENT 'Resulting TT based on related TT formula [s]',
  `model_type` varchar(25) CHARACTER SET utf8 NOT NULL COMMENT 'Model used for calculation of TT',
  `confidence` int(11) DEFAULT NULL COMMENT 'Customer confidence for complete TT based on related confidence formula [%]',
  `calc_note` varchar(1024) COLLATE utf8_czech_ci DEFAULT NULL COMMENT 'Travel time calculation note',
  `calc_delay` float NOT NULL COMMENT 'Delay of output section TT calculation',
  `insert_timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Timestamp or record insertion',
  PRIMARY KEY (`calculation_time`,`output_section`,`model_type`),
  KEY `calctimelocal_section_idx` (`calculation_time_local`,`output_section`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci COMMENT='Final TT for output sections.';
