"""
Module ``general_settings``.

Contain settings about the prediction & training intervals, paths to dumped data, calculator.

"""
from ..models import ClusterModel, TimeDomainModel, CombinedModel

#: Path to ``calculator of real traveltimes`` - it is used for the calculation of the ground truth necessary for the training
real_tt_calculator_path = ""

#: Path to dumped features` folder - folder, where the dumped features are stored - to avoid frequent heavy DB queries
dumped_features_path = ""

#: Offset in seconds from start of the first training, when prediction will be run for the first time
prediction_first_run_offset = 120

#: Prediction interval in seconds
prediction_interval_seconds = 60

#: Training interval in seconds
training_interval_seconds = 3600*24  # seconds

#: Data to be retrieved for training in days
training_data_interval = 30  # days

#: Allowed models to be used by prediction system
all_models = {ClusterModel, TimeDomainModel, CombinedModel}

#: Max allowed traveltime predicted - used for coercing nonsense values produced by models
max_traveltime = 60*60*2