from .cluster_model import ClusterModel
from .time_domain_model import TimeDomainModel
from .combined_model import CombinedModel
from .create_model import create_model, model_translator, params_converter

from .algorithms import RidgeWrapper, LinearRegressionWrapper, ElasticNetWrapper, MBKMeansWrapper


params_grids_training = {
    TimeDomainModel.name:

        [{'regressor': RidgeWrapper, 'regressor_params': {'alpha': alpha, 'tol': tol}}
         for alpha in
         [1, 5, 10, 20, 30, 50, 100, 200, 300, 500, 750, 1000]
         for tol in [100, 30, 10, 1, 1e-1, 1e-5, 1e-9]]
,
    ClusterModel.name:
        [{'regressor': RidgeWrapper,
                             'regressor_params': {'alpha': alpha, 'tol': tol},
                             'clusterizer': MBKMeansWrapper,
                             'clusterizer_params': {'n_clusters': n}}
         for n in [1, 2, 5, 10, 25, 50, 75, 100, 150, 200]
         for alpha in [1, 5, 10, 25, 50, 100, 250, 500, 750, 1000, 1500, 2000]
         for tol in [100, 50, 25, 10, 1, 1e-1, 1e-5, 1e-9]
         ]
,
    CombinedModel.name:
        [{'models': {'T1': TimeDomainModel, 'C1': ClusterModel},
          'models_params': {'T1': {'regressor': RidgeWrapper,
                                   'regressor_params': {'alpha': alpha, 'tol': tol}},
                            'C1': {'regressor': LinearRegressionWrapper,
                                   'regressor_params': {},
                                   'clusterizer': MBKMeansWrapper,
                                   'clusterizer_params': {'n_clusters': n}},
                            }

                            }
                            for alpha in [1, 5, 10, 25, 50, 100, 250, 500, 1000]
                            for tol in [100, 50, 25, 10, 1, 1e-3]
                            for n in [1, 5, 10, 25, 50, 75, 100, 150]
         ]
}